==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/PeacefulModItems.java <==
package xen42.peacefulitems;

import java.util.HashMap;
import java.util.Map;
import java.util.function.Function;

import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.fabricmc.fabric.api.registry.CompostingChanceRegistry;
import net.fabricmc.fabric.api.registry.FuelRegistry;
import net.fabricmc.fabric.api.transfer.v1.fluid.CauldronFluidContent;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidConstants;
import net.minecraft.class_1269;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_174;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1814;
import net.minecraft.class_1853;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2315;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3765;
import net.minecraft.class_4174;
import net.minecraft.class_5321;
import net.minecraft.class_5556;
import net.minecraft.class_5620;
import net.minecraft.class_7706;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.class_8779;
import net.minecraft.class_9283;
import xen42.peacefulitems.item.DispensibleSpawnEggItem;
import xen42.peacefulitems.item.EffigyItem;
import xen42.peacefulitems.blocks.DragonBreathCauldronBlock;
import xen42.peacefulitems.item.BrushDispenserBehavior;
import xen42.peacefulitems.item.CapeItem;
import xen42.peacefulitems.mixin.EnderDragonFight_Invoker;

public class PeacefulModItems {
    public static final class_1792 BAT_WING = register("bat_wing", class_1792::new, new class_1792.class_1793());
    
    public static final class_2960 CAPE_EQUIPMENT_ASSET = class_2960.method_43902(PeacefulMod.MOD_ID, "cape");
    public static final class_1792 CAPE = register("cape", CapeItem::new,
        new class_1792.class_1793()
            .method_7895(108)
            .method_7894(class_1814.field_8906));
    
    public static final class_1792 ECTOPLASM = register("ectoplasm", class_1792::new, new class_1792.class_1793());
    public static final class_1792 GUANO = register("guano", class_1792::new, new class_1792.class_1793());
    public static final class_1792 SULPHUR = register("sulphur", (settings) -> new class_1747(PeacefulModBlocks.SULPHUR_CLUSTER, settings), new class_1792.class_1793());
    public static final class_1792 FLAX = register("flax", (settings) -> 
        new class_1747(PeacefulModBlocks.FLAX_CROP, settings) {
            @Override
            public class_1269 method_7712(class_1750 context) {
            	class_1269 result = super.method_7712(context);
                if (result == class_1269.field_5812)
                {
                    // Grant the player the "A Seedy Place" advancement
                    if (context.method_8036() instanceof class_3222 player && player.method_5682() != null)
                    {
                    	class_8779 seedyPlace = player.method_5682().method_3851().method_12896(class_2960.method_43902("minecraft","husbandry/plant_seed"));
                        if (seedyPlace != null)
                        {
                        	String first = seedyPlace.comp_1920().comp_1915().keySet().iterator().next();
                        	player.method_14236().method_12878(seedyPlace, first);
                        }
                    }
                }
                return result;
            }
        }, new class_1792.class_1793().method_19265(new class_4174.class_4175().method_19238(2).method_19237(1F).method_19242()));
    public static final class_1792 GHASTLING_SPAWN_EGG = register("ghastling_spawn_egg", (settings) -> 
        new DispensibleSpawnEggItem(PeacefulMod.GHASTLING_ENTITY, 0xFFFFFF, 0x7A7A7A, settings), new class_1792.class_1793());
    public static final class_1792 END_CLAM_SPAWN_EGG = register("end_clam_spawn_egg", (settings) -> 
        new DispensibleSpawnEggItem(PeacefulMod.END_CLAM_ENTITY, 0x6F4B6F, 0x2B1E2B, settings), new class_1792.class_1793());
    public static final class_1792 WITHER_EFFIGY = register("wither_effigy", (settings) -> 
        new EffigyItem(settings, "wither_effigy", (class_3222 user) -> {
            user.method_5706(class_1802.field_8137);
        }, class_3417.field_15136),
        new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8907));

    public static final class_1792 GUARDIAN_EFFIGY = register("guardian_effigy", (settings) -> 
        new EffigyItem(settings, "guardian_effigy", (class_3222 user) -> { 
            var world = user.method_51469();

            user.method_5706(class_2246.field_10258);
            if (user.method_6051().method_43057() < 0.2) {
                user.method_5706(class_1802.field_41954);
            }

            // Will drop more as if you had killed multiple guardians (which you would normally)
            user.method_5775(new class_1799(class_1802.field_8373, user.method_6051().method_39332(1, 6)));
            user.method_5775(new class_1799(class_1802.field_8434, user.method_6051().method_39332(2, 12)));
            user.method_5775(new class_1799(class_1802.field_8662, user.method_6051().method_39332(2, 8)));

        }, class_3417.field_15203),
        new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8907));
    
    public static final class_1792 DRAGON_EFFIGY = register("dragon_effigy", (settings) -> 
        new EffigyItem(settings, "dragon_effigy", (class_3222 user) -> {
            class_3218 end = user.method_5682().method_3847(class_1937.field_25181);
            var fight = end.method_29198();
            ((EnderDragonFight_Invoker)fight).invokeGenerateNewEndGateway();
        }, class_3417.field_14773), new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8907));

    public static final class_1792 RAID_EFFIGY = register("raid_effigy", (settings) -> 
        new EffigyItem(settings, "raid_effigy", (class_3222 user) -> {
            user.method_6092(new class_1293(class_1294.field_18980, 48000, 1, false, false, true));
            class_174.field_19250.method_9141(user);
            var r = user.method_6051().method_43057();
            var world = user.method_51469();
            // Bunch of different raid drops excluding Totem of Undying
            if (r < 0.5) {
                user.method_5706(class_1802.field_50140);
            }
            else {
                user.method_5775(class_3765.method_16515(world.method_30349().method_46762(class_7924.field_41252)));
            }
            if (r < 0.33) {
                user.method_5706(class_1802.field_8399);
            }
            if (r < 0.33) {
                user.method_5706(class_1802.field_8175);
            }
            if (r < 0.33) {
                user.method_5706(class_1802.field_8475);
            }

            user.method_5775(new class_1799(class_1802.field_8687, user.method_6051().method_39332(1, 20)));

            // Witch drops
            user.method_5775(new class_1799(class_2246.field_10091, user.method_6051().method_39332(1, 12)));
            user.method_5775(new class_1799(class_1802.field_8054, user.method_6051().method_39332(1, 12)));
            user.method_5775(new class_1799(class_1802.field_8600, user.method_6051().method_39332(1, 12)));
            user.method_5775(new class_1799(class_1802.field_8601, user.method_6051().method_39332(1, 12)));
            user.method_5775(new class_1799(class_1802.field_8479, user.method_6051().method_39332(1, 12)));
            user.method_5775(new class_1799(class_1802.field_8680, user.method_6051().method_39332(1, 12)));
            user.method_5775(new class_1799(class_1802.field_8469, user.method_6051().method_39332(1, 12)));
        }, class_3417.field_17266), new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8907));

    public static final class_1792 CLAM = register("clam_meat", class_1792::new, 
        new class_1792.class_1793().method_19265(new class_4174.class_4175().method_19238(5).method_19237(0.6F).method_19239(new class_1293(class_1294.field_5903, 600, 0), 0.3F).method_19242()));
    
    public static final class_1792 COOKED_CLAM = register("cooked_clam_meat", class_1792::new, 
        new class_1792.class_1793().method_19265(new class_4174.class_4175().method_19238(5).method_19237(0.6F).method_19242()));

    public static void initialize() {
        // Add custom items to groups
        ItemGroupEvents.modifyEntriesEvent(class_7706.field_40195).register((itemGroup) -> {
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_BLOCK.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_STAIRS.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_SLAB.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_WALL.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.CHISELED_SULPHUR_BLOCK.method_8389());
        });
        
        ItemGroupEvents.modifyEntriesEvent(class_7706.field_41062).register((itemGroup) -> { 
            itemGroup.method_45421(BAT_WING);
            itemGroup.method_45421(ECTOPLASM);
            itemGroup.method_45421(GUANO);
            itemGroup.method_45421(SULPHUR);
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_40743).register((itemGroup) -> {
            itemGroup.method_45421(FLAX);
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_BLOCK.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_ORE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_CLUSTER.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.FOSSIL_ORE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.DEEPSLATE_FOSSIL_ORE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SOUL_SOIL_FOSSIL_ORE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.BLAZE_PICKLE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.BREEZE_CORAL.method_8389());
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_41061).register((itemGroup) -> { 
            itemGroup.method_45421(FLAX);
            itemGroup.method_45421(CLAM);
            itemGroup.method_45421(COOKED_CLAM);
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_40205).register((itemGroup) -> {
            itemGroup.method_45421(GHASTLING_SPAWN_EGG);
            itemGroup.method_45421(END_CLAM_SPAWN_EGG);
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_41060).register((itemGroup) -> {
            itemGroup.method_45421(CAPE);
            itemGroup.method_45421(WITHER_EFFIGY);
            itemGroup.method_45421(DRAGON_EFFIGY);
            itemGroup.method_45421(GUARDIAN_EFFIGY);
            itemGroup.method_45421(RAID_EFFIGY);
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_40197).register((itemGroup) -> {
            itemGroup.method_45421(PeacefulModBlocks.EFFIGY_ALTAR.method_8389());
            itemGroup.method_45421(class_2246.field_27097.method_8389());
            itemGroup.method_45421(class_2246.field_27098.method_8389());
            itemGroup.method_45421(class_2246.field_27878.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.DRAGON_BREATH_CAULDRON.method_8389());
        });

        CompostingChanceRegistry.INSTANCE.add(GUANO, 2f);
        CompostingChanceRegistry.INSTANCE.add(FLAX, 0.3f);

        int sulphurTime = 200 * 4; // More useful than wood, but not as good as coal
        FuelRegistry.INSTANCE.add(PeacefulModItems.SULPHUR, sulphurTime);
        int sulphurBlockTime = sulphurTime * 10; // Coal blocks are 10 times so we do that too
        FuelRegistry.INSTANCE.add(PeacefulModBlocks.SULPHUR_BLOCK, sulphurBlockTime);
        FuelRegistry.INSTANCE.add(PeacefulModBlocks.SULPHUR_WALL, sulphurBlockTime);
        FuelRegistry.INSTANCE.add(PeacefulModBlocks.CHISELED_SULPHUR_BLOCK, sulphurBlockTime);
        FuelRegistry.INSTANCE.add(PeacefulModBlocks.SULPHUR_SLAB, sulphurBlockTime / 2); // 2/4
        FuelRegistry.INSTANCE.add(PeacefulModBlocks.SULPHUR_STAIRS, sulphurBlockTime / (4 / 3)); // 3/4

        class_2315.method_10009(class_1802.field_42716.method_8389(), new BrushDispenserBehavior());

        CauldronFluidContent.registerCauldron(PeacefulModBlocks.DRAGON_BREATH_CAULDRON, PeacefulModFluids.DRAGON_BREATH, FluidConstants.BOTTLE, class_5556.field_27206);
        class_5620.field_27775.comp_1982().put(DRAGON_EFFIGY, new DragonBreathCauldronBlock.FillFromEffigyBehavior());
        class_5620.field_27775.comp_1982().put(class_1802.field_8613, new DragonBreathCauldronBlock.FillFromBottleBehavior());
        DragonBreathCauldronBlock.DRAGON_BREATH_CAULDRON_BEHAVIOR.comp_1982().put(class_1802.field_8469, new DragonBreathCauldronBlock.DecrementFluidLevelBehavior());
        DragonBreathCauldronBlock.DRAGON_BREATH_CAULDRON_BEHAVIOR.comp_1982().put(class_1802.field_8613, new DragonBreathCauldronBlock.IncrementFluidLevelBehavior());
        
        // Replace the original immutable map with a mutable one and add custom items
        Map<class_1792, class_9283.class_1782> fireworkExplosionTypeModifierMap = new HashMap<>(class_1853.field_9013);
        fireworkExplosionTypeModifierMap.put(PeacefulModBlocks.BLAZE_PICKLE.method_8389(), class_9283.class_1782.field_7977);
        fireworkExplosionTypeModifierMap.put(PeacefulModBlocks.BREEZE_CORAL.method_8389(), class_9283.class_1782.field_7970);
        class_1853.field_9013 = fireworkExplosionTypeModifierMap;
    }

    public static class_1792 register(String name, Function<class_1792.class_1793, class_1792> itemFactory, class_1792.class_1793 settings) {
		// Create the item key.
		class_5321<class_1792> itemKey = class_5321.method_29179(class_7924.field_41197, class_2960.method_43902(PeacefulMod.MOD_ID, name));

		// Create the item instance.
		class_1792 item = itemFactory.apply(settings);

		// Register the item.
		class_2378.method_39197(class_7923.field_41178, itemKey, item);

		return item;
	}
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/PeacefulModItems.java <==
package xen42.peacefulitems;

import java.util.HashMap;
import java.util.Map;
import java.util.function.Function;

import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.fabricmc.fabric.api.registry.CompostingChanceRegistry;
import net.fabricmc.fabric.api.registry.FuelRegistryEvents;
import net.fabricmc.fabric.api.transfer.v1.fluid.CauldronFluidContent;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidConstants;
import net.minecraft.class_10128;
import net.minecraft.class_10191;
import net.minecraft.class_10192;
import net.minecraft.class_10394;
import net.minecraft.class_1269;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1304;
import net.minecraft.class_174;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1814;
import net.minecraft.class_1853;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2315;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3765;
import net.minecraft.class_3902;
import net.minecraft.class_4174;
import net.minecraft.class_5321;
import net.minecraft.class_5556;
import net.minecraft.class_5620;
import net.minecraft.class_7706;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.class_8779;
import net.minecraft.class_9283;
import net.minecraft.class_9334;
import xen42.peacefulitems.item.DispensibleSpawnEggItem;
import xen42.peacefulitems.item.EffigyItem;
import xen42.peacefulitems.blocks.DragonBreathCauldronBlock;
import xen42.peacefulitems.item.BrushDispenserBehavior;
import xen42.peacefulitems.mixin.EnderDragonFight_Invoker;

public class PeacefulModItems {
    public static final class_1792 BAT_WING = register("bat_wing", class_1792::new, new class_1792.class_1793());
    
    public static final class_5321<class_10394> CAPE_EQUIPMENT_ASSET = class_5321.method_29179(class_10191.field_55214, class_2960.method_60655(PeacefulMod.MOD_ID, "cape"));
    public static final class_1792 CAPE = register("cape", class_1792::new,
        new class_1792.class_1793()
            .method_7895(108)
            .method_7894(class_1814.field_8906)
            .method_57349(class_9334.field_54197, class_3902.field_17274)
            .method_57349(
                class_9334.field_54196,
                class_10192.method_64202(class_1304.field_6174)
                    .method_64205(class_3417.field_14966)
                    .method_64204(CAPE_EQUIPMENT_ASSET)
                    .method_64210(false)
                    .method_64203()
            )
            .method_61648(BAT_WING));
    
    public static final class_1792 ECTOPLASM = register("ectoplasm", class_1792::new, new class_1792.class_1793());
    public static final class_1792 GUANO = register("guano", class_1792::new, new class_1792.class_1793());
    public static final class_1792 SULPHUR = register("sulphur", (settings) -> new class_1747(PeacefulModBlocks.SULPHUR_CLUSTER, settings), new class_1792.class_1793());
    public static final class_1792 FLAX = register("flax", (settings) -> 
        new class_1747(PeacefulModBlocks.FLAX_CROP, settings) {
            @Override
            public class_1269 method_7712(class_1750 context) {
            	class_1269 result = super.method_7712(context);
                if (result == class_1269.field_5812)
                {
                    // Grant the player the "A Seedy Place" advancement
                    if (context.method_8036() instanceof class_3222 player && player.method_51469().method_8503() != null)
                    {
                    	class_8779 seedyPlace = player.method_51469().method_8503().method_3851().method_12896(class_2960.method_60656("husbandry/plant_seed"));
                        if (seedyPlace != null)
                        {
                        	String first = seedyPlace.comp_1920().comp_1915().keySet().iterator().next();
                        	player.method_14236().method_12878(seedyPlace, first);
                        }
                    }
                }
                return result;
            }
        }, new class_1792.class_1793().method_19265(new class_4174(2, 1, false)));
    public static final class_1792 GHASTLING_SPAWN_EGG = register("ghastling_spawn_egg", DispensibleSpawnEggItem::new, new class_1792.class_1793().method_72499(PeacefulMod.GHASTLING_ENTITY));
    public static final class_1792 END_CLAM_SPAWN_EGG = register("end_clam_spawn_egg", DispensibleSpawnEggItem::new, new class_1792.class_1793().method_72499(PeacefulMod.END_CLAM_ENTITY));
    public static final class_1792 WITHER_EFFIGY = register("wither_effigy", (settings) -> 
        new EffigyItem(settings, "wither_effigy", (class_3222 user) -> {
            user.method_5706(user.method_51469(), class_1802.field_8137);
        }, class_3417.field_15136),
        new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8907));

    public static final class_1792 GUARDIAN_EFFIGY = register("guardian_effigy", (settings) -> 
        new EffigyItem(settings, "guardian_effigy", (class_3222 user) -> { 
            var world = user.method_51469();

            user.method_5706(world, class_2246.field_10258);
            if (user.method_59922().method_43057() < 0.2) {
                user.method_5706(world, class_1802.field_41954);
            }

            // Will drop more as if you had killed multiple guardians (which you would normally)
            user.method_5775(world, new class_1799(class_1802.field_8373, user.method_59922().method_39332(1, 6)));
            user.method_5775(world, new class_1799(class_1802.field_8434, user.method_59922().method_39332(2, 12)));
            user.method_5775(world, new class_1799(class_1802.field_8662, user.method_59922().method_39332(2, 8)));

        }, class_3417.field_15203),
        new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8907));
    
    public static final class_1792 DRAGON_EFFIGY = register("dragon_effigy", (settings) -> 
        new EffigyItem(settings, "dragon_effigy", (class_3222 user) -> {
            class_3218 end = user.method_51469().method_8503().method_3847(class_1937.field_25181);
            var fight = end.method_29198();
            ((EnderDragonFight_Invoker)fight).invokeGenerateNewEndGateway();
        }, class_3417.field_14773), new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8907));

    public static final class_1792 RAID_EFFIGY = register("raid_effigy", (settings) -> 
        new EffigyItem(settings, "raid_effigy", (class_3222 user) -> {
            user.method_6092(new class_1293(class_1294.field_18980, 48000, 1, false, false, true));
            class_174.field_19250.method_9141(user);
            var r = user.method_59922().method_43057();
            var world = user.method_51469();
            // Bunch of different raid drops excluding Totem of Undying
            if (r < 0.5) {
                user.method_5706(world, class_1802.field_50140);
            }
            else {
                user.method_5775(world, class_3765.method_61558(world.method_30349().method_30530(class_7924.field_41252)));
            }
            if (r < 0.33) {
                user.method_5706(world, class_1802.field_8399);
            }
            if (r < 0.33) {
                user.method_5706(world, class_1802.field_8175);
            }
            if (r < 0.33) {
                user.method_5706(world, class_1802.field_8475);
            }

            user.method_5775(world, new class_1799(class_1802.field_8687, user.method_59922().method_39332(1, 20)));

            // Witch drops
            user.method_5775(world, new class_1799(class_2246.field_10091, user.method_59922().method_39332(1, 12)));
            user.method_5775(world, new class_1799(class_1802.field_8054, user.method_59922().method_39332(1, 12)));
            user.method_5775(world, new class_1799(class_1802.field_8600, user.method_59922().method_39332(1, 12)));
            user.method_5775(world, new class_1799(class_1802.field_8601, user.method_59922().method_39332(1, 12)));
            user.method_5775(world, new class_1799(class_1802.field_8479, user.method_59922().method_39332(1, 12)));
            user.method_5775(world, new class_1799(class_1802.field_8680, user.method_59922().method_39332(1, 12)));
            user.method_5775(world, new class_1799(class_1802.field_8469, user.method_59922().method_39332(1, 12)));
        }, class_3417.field_17266), new class_1792.class_1793().method_7889(1).method_7894(class_1814.field_8907));

    public static final class_1792 CLAM = register("clam_meat", class_1792::new, 
        new class_1792.class_1793().method_62833(new class_4174(5, 0.6f, false), class_10128.field_53784));
    
    public static final class_1792 COOKED_CLAM = register("cooked_clam_meat", class_1792::new, 
        new class_1792.class_1793().method_19265(new class_4174(5, 0.6f, false)));

    public static void initialize() {
        // Add custom items to groups
        ItemGroupEvents.modifyEntriesEvent(class_7706.field_40195).register((itemGroup) -> {
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_BLOCK.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_STAIRS.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_SLAB.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_WALL.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.CHISELED_SULPHUR_BLOCK.method_8389());
        });
        
        ItemGroupEvents.modifyEntriesEvent(class_7706.field_41062).register((itemGroup) -> { 
            itemGroup.method_45421(BAT_WING);
            itemGroup.method_45421(ECTOPLASM);
            itemGroup.method_45421(GUANO);
            itemGroup.method_45421(SULPHUR);
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_40743).register((itemGroup) -> {
            itemGroup.method_45421(FLAX);
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_BLOCK.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_ORE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SULPHUR_CLUSTER.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.FOSSIL_ORE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.DEEPSLATE_FOSSIL_ORE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.SOUL_SOIL_FOSSIL_ORE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.BLAZE_PICKLE.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.BREEZE_CORAL.method_8389());
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_41061).register((itemGroup) -> { 
            itemGroup.method_45421(FLAX);
            itemGroup.method_45421(CLAM);
            itemGroup.method_45421(COOKED_CLAM);
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_40205).register((itemGroup) -> {
            itemGroup.method_45421(GHASTLING_SPAWN_EGG);
            itemGroup.method_45421(END_CLAM_SPAWN_EGG);
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_41060).register((itemGroup) -> {
            itemGroup.method_45421(CAPE);
            itemGroup.method_45421(WITHER_EFFIGY);
            itemGroup.method_45421(DRAGON_EFFIGY);
            itemGroup.method_45421(GUARDIAN_EFFIGY);
            itemGroup.method_45421(RAID_EFFIGY);
        });

        ItemGroupEvents.modifyEntriesEvent(class_7706.field_40197).register((itemGroup) -> {
            itemGroup.method_45421(PeacefulModBlocks.EFFIGY_ALTAR.method_8389());
            itemGroup.method_45421(class_2246.field_27097.method_8389());
            itemGroup.method_45421(class_2246.field_27098.method_8389());
            itemGroup.method_45421(class_2246.field_27878.method_8389());
            itemGroup.method_45421(PeacefulModBlocks.DRAGON_BREATH_CAULDRON.method_8389());
        });

        CompostingChanceRegistry.INSTANCE.add(GUANO, 2f);
        CompostingChanceRegistry.INSTANCE.add(FLAX, 0.3f);

        FuelRegistryEvents.BUILD.register((builder, context) -> {
            int sulphurTime = context.baseSmeltTime() * 4; // More useful than wood, but not as good as coal
            builder.method_61762(PeacefulModItems.SULPHUR, sulphurTime);
            int sulphurBlockTime = sulphurTime * 10; // Coal blocks are 10 times so we do that too
            builder.method_61762(PeacefulModBlocks.SULPHUR_BLOCK, sulphurBlockTime);
            builder.method_61762(PeacefulModBlocks.SULPHUR_WALL, sulphurBlockTime);
            builder.method_61762(PeacefulModBlocks.CHISELED_SULPHUR_BLOCK, sulphurBlockTime);
            builder.method_61762(PeacefulModBlocks.SULPHUR_SLAB, sulphurBlockTime / 2); // 2/4
            builder.method_61762(PeacefulModBlocks.SULPHUR_STAIRS, sulphurBlockTime / (4 / 3)); // 3/4
        });

        class_2315.method_10009(class_1802.field_42716.method_8389(), new BrushDispenserBehavior());

        CauldronFluidContent.registerCauldron(PeacefulModBlocks.DRAGON_BREATH_CAULDRON, PeacefulModFluids.DRAGON_BREATH, FluidConstants.BOTTLE, class_5556.field_27206);
        class_5620.field_27775.comp_1982().put(DRAGON_EFFIGY, new DragonBreathCauldronBlock.FillFromEffigyBehavior());
        class_5620.field_27775.comp_1982().put(class_1802.field_8613, new DragonBreathCauldronBlock.FillFromBottleBehavior());
        DragonBreathCauldronBlock.DRAGON_BREATH_CAULDRON_BEHAVIOR.comp_1982().put(class_1802.field_8469, new DragonBreathCauldronBlock.DecrementFluidLevelBehavior());
        DragonBreathCauldronBlock.DRAGON_BREATH_CAULDRON_BEHAVIOR.comp_1982().put(class_1802.field_8613, new DragonBreathCauldronBlock.IncrementFluidLevelBehavior());
        
        // Replace the original immutable map with a mutable one and add custom items
        Map<class_1792, class_9283.class_1782> fireworkExplosionTypeModifierMap = new HashMap<>(class_1853.field_9013);
        fireworkExplosionTypeModifierMap.put(PeacefulModBlocks.BLAZE_PICKLE.method_8389(), class_9283.class_1782.field_7977);
        fireworkExplosionTypeModifierMap.put(PeacefulModBlocks.BREEZE_CORAL.method_8389(), class_9283.class_1782.field_7970);
        class_1853.field_9013 = fireworkExplosionTypeModifierMap;
    }

    public static class_1792 register(String name, Function<class_1792.class_1793, class_1792> itemFactory, class_1792.class_1793 settings) {
		// Create the item key.
		class_5321<class_1792> itemKey = class_5321.method_29179(class_7924.field_41197, class_2960.method_60655(PeacefulMod.MOD_ID, name));

		// Create the item instance.
		class_1792 item = itemFactory.apply(settings.method_63686(itemKey));

		// Register the item.
		class_2378.method_39197(class_7923.field_41178, itemKey, item);

		return item;
	}
}
